@@ -10,7 +10,7 @@ import zlib
 from Crypto.Cipher import DES
 from contextlib import contextmanager
 from enum import Enum
-from typing import Any, Callable, Generator, List, Optional, Union, cast
+from typing import Any, Callable, Dict, Generator, List, Optional, Union, cast
 
 from arcadeutils import FileBytes
 
@@ -34,6 +34,13 @@ class NetDimmVersionEnum(Enum):
     VERSION_4_02 = "4.02"
 
 
+class NetDimmTargetEnum(Enum):
+    TARGET_UNKNOWN = "unknown"
+    TARGET_CHIHIRO = "chihiro"
+    TARGET_NAOMI = "naomi"
+    TARGET_TRIFORCE = "triforce"
+
+
 class CRCStatusEnum(Enum):
     STATUS_CHECKING = 1
     STATUS_VALID = 2
@@ -83,6 +90,13 @@ class NetDimmPacket:
 
 
 class NetDimm:
+    DEFAULT_TIMEOUTS: Dict[NetDimmTargetEnum, int] = {
+        NetDimmTargetEnum.TARGET_UNKNOWN: 15,
+        NetDimmTargetEnum.TARGET_NAOMI: 15,
+        NetDimmTargetEnum.TARGET_CHIHIRO: 40,
+        NetDimmTargetEnum.TARGET_TRIFORCE: 40,
+    }
+
     @staticmethod
     def crc(data: Union[bytes, FileBytes]) -> int:
         crc: int = 0
@@ -100,15 +114,30 @@ class NetDimm:
         self,
         ip: str,
         version: Optional[NetDimmVersionEnum] = None,
+        target: Optional[NetDimmTargetEnum] = None,
         log: Optional[Callable[..., Any]] = None,
+        timeout: Optional[int] = None,
     ) -> None:
         self.ip: str = ip
         self.sock: Optional[socket.socket] = None
         self.log: Optional[Callable[..., Any]] = log
         self.version: NetDimmVersionEnum = version or NetDimmVersionEnum.VERSION_UNKNOWN
+        self.target: NetDimmTargetEnum = target or NetDimmTargetEnum.TARGET_UNKNOWN
+
+        # A sane default for different targets, at least in my testing, is 10 seconds. However, OSX
+        # users and some people have reported that this is too fast. So, 15 seconds it is for everything.
+        # User reports for Chihiro are that it is super slow, so it needs a longer timeout. I have no
+        # idea on Triforce so I set it the same as Chihiro.
+        default_timeout = NetDimm.DEFAULT_TIMEOUTS[self.target]
+        if timeout is None:
+            try:
+                timeout = int(os.environ.get('NETDIMM_TIMEOUT_SECONDS') or default_timeout)
+            except Exception:
+                timeout = default_timeout
+        self.timeout: int = timeout
 
     def __repr__(self) -> str:
-        return f"NetDimm(ip={repr(self.ip)}, version={repr(self.version)})"
+        return f"NetDimm(ip={repr(self.ip)}, version={repr(self.version)}, target={repr(self.target)}, timeout={repr(self.timeout)})"
 
     def info(self) -> NetDimmInfo:
         with self.connection():
@@ -299,13 +328,13 @@ class NetDimm:
             # on OSX and you set 'ALTERNATE_TIMEOUT_HANDLING' the alternate will be enabled
             # as well.
             if (sys.platform == 'darwin' or os.environ.get('ALTERNATE_TIMEOUT_HANDLING')) and (not os.environ.get('DEFAULT_TIMEOUT_HANDLING')):
-                self.sock.settimeout(15)
+                self.sock.settimeout(self.timeout)
                 self.sock.setblocking(True)
                 self.sock.connect((self.ip, 10703))
             else:
                 self.sock.settimeout(1)
                 self.sock.connect((self.ip, 10703))
-                self.sock.settimeout(15)
+                self.sock.settimeout(self.timeout)
 
         except Exception as e:
             raise NetDimmException("Could not connect to NetDimm") from e
